package Qt::Gui::QIconEnginePlugin;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QIconEnginePlugin
# file     : QtGui/qiconengineplugin.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QIconEngineFactoryInterface/;
#our @ISA = qw/Qt::Gui::QIconEngineFactoryInterface/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QIconEnginePlugin

=head1 PUBLIC METHODS

=over

=item   QIconEnginePlugin(QObject * parent)

=item   QIconEnginePlugin(QObject * parent = 0)

=item   ~QIconEnginePlugin()

=item  QIconEngine * create(const QString & filename)

=item  QStringList keys()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
